==> nextcloud-27.1.11.tgz: nextcloud/apps/files_reminders/l10n/ga.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Meabhrúcháin comhaid",
    "Reminder for {name}" : "Meabhrúchán do {name}",
    "View file" : "Féach ar chomhad",
    "View folder" : "Féach ar fhillteán",
    "Set file reminders" : "Socraigh meabhrúcháin comhaid",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Meabhrúcháin comhaid**\n\nSocraigh meabhrúcháin comhaid.",
    "We will remind you of this file" : "Cuirfimid an comhad seo i gcuimhne duit",
    "Please choose a valid date & time" : "Roghnaigh dáta agus am bailí le do thoil",
    "Cancel" : "Cealaigh",
    "Clear reminder" : "Meabhrúchán soiléir",
    "Set reminder" : "Socraigh meabhrúchán",
    "Set reminder for \"{fileName}\"" : "Socraigh meabhrúchán do \"{fileName}\"",
    "Set reminder at custom date & time" : "Socraigh meabhrúchán ar dháta agus am saincheaptha",
    "Reminder set for \"{fileName}\"" : "Meabhrúchán socraithe do \"{fileName}\"",
    "Failed to set reminder" : "Theip ar an meabhrúchán a shocrú",
    "Reminder cleared for \"{fileName}\"" : "Glanadh an meabhrúchán le haghaidh \"{fileName}\"",
    "Failed to clear reminder" : "Theip ar an meabhrúchán a ghlanadh",
    "Reminder set" : "Meabhrúchán socraithe",
    "Set custom reminder" : "Socraigh meabhrúchán saincheaptha",
    "Later today" : "Níos déanaí inniu",
    "Set reminder for later today" : "Socraigh meabhrúchán le haghaidh níos déanaí inniu",
    "Tomorrow" : "Amárach",
    "Set reminder for tomorrow" : "Socraigh meabhrúchán don lá amárach",
    "This weekend" : "An deireadh seachtaine seo",
    "Set reminder for this weekend" : "Socraigh meabhrúchán don deireadh seachtaine seo",
    "Next week" : "An tseachtain seo chugainn",
    "Set reminder for next week" : "Socraigh meabhrúchán don tseachtain seo chugainn",
    "Back" : "Ar ais",
    "Reminder cleared" : "Meabhrúchán glanta",
    "Failed to load reminder" : "Theip ar an meabhrúchán a lódáil"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-28.0.14.tgz: nextcloud/apps/files_reminders/l10n/ga.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Meabhrúcháin comhaid",
    "Reminder for {name}" : "Meabhrúchán do {name}",
    "View file" : "Féach ar chomhad",
    "View folder" : "Féach ar fhillteán",
    "Set file reminders" : "Socraigh meabhrúcháin comhaid",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Meabhrúcháin comhaid**\n\nSocraigh meabhrúcháin comhaid.\n\nTabhair faoi deara: chun an aip `Meabhrúcháin Comhad` a úsáid, cinntigh go bhfuil an aip `Fógraí` suiteáilte agus cumasaithe. Soláthraíonn an aip `Fógraí` na APInna riachtanacha chun go n-oibreoidh an aip `Meabhrúcháin Comhad` i gceart.",
    "We will remind you of this file" : "Cuirfimid an comhad seo i gcuimhne duit",
    "Please choose a valid date & time" : "Roghnaigh dáta agus am bailí le do thoil",
    "Cancel" : "Cealaigh",
    "Clear reminder" : "Meabhrúchán soiléir",
    "Set reminder" : "Socraigh meabhrúchán",
    "Set reminder for \"{fileName}\"" : "Socraigh meabhrúchán do \"{fileName}\"",
    "Set reminder at custom date & time" : "Socraigh meabhrúchán ar dháta agus am saincheaptha",
    "Reminder set for \"{fileName}\"" : "Meabhrúchán socraithe do \"{fileName}\"",
    "Failed to set reminder" : "Theip ar an meabhrúchán a shocrú",
    "Reminder cleared for \"{fileName}\"" : "Glanadh an meabhrúchán le haghaidh \"{fileName}\"",
    "Failed to clear reminder" : "Theip ar an meabhrúchán a ghlanadh",
    "Reminder set" : "Meabhrúchán socraithe",
    "Set custom reminder" : "Socraigh meabhrúchán saincheaptha",
    "Later today" : "Níos déanaí inniu",
    "Set reminder for later today" : "Socraigh meabhrúchán le haghaidh níos déanaí inniu",
    "Tomorrow" : "Amárach",
    "Set reminder for tomorrow" : "Socraigh meabhrúchán don lá amárach",
    "This weekend" : "An deireadh seachtaine seo",
    "Set reminder for this weekend" : "Socraigh meabhrúchán don deireadh seachtaine seo",
    "Next week" : "An tseachtain seo chugainn",
    "Set reminder for next week" : "Socraigh meabhrúchán don tseachtain seo chugainn",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Meabhrúcháin comhaid**\n\nSocraigh meabhrúcháin comhaid."
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
